////////////////////////////////////////////////////////////////////////////////
// Module    : Win2600.c
// Function  : DLL Startup/Shutdown functions and DLL function pointers.
// Usage     : Linked by all Windows apps that access S2600.DLL functions.
// Author    : Jim Lamberson
// Copyright : (C) 2004 Sensoray
////////////////////////////////////////////////////////////////////////////////

#include <windows.h>
#include <stdio.h>

// The DLL handle.
static HINSTANCE hlib;

// Instantiate the DLL function pointers.
#define XFUNC26(RTYP,FNAM,ARGS)		RTYP ( __stdcall *FNAM ) ARGS
#include "f2600.h"

//////////////////////////////////////////
// Populate the DLL function pointers.
// Returns 0 if pointers successfully initialized.

static int GetFuncPtrs( void )
{
#undef XFUNC26
#define XFUNC26(RTYP,FNAM,ARGS)	{ if ( (FNAM = ( RTYP ( __stdcall * ) ARGS )GetProcAddress( hlib, #FNAM )) == NULL ) return -1; }
#include "f2600.h"	// Initialize function pointers; return -1 if failed.

	return 0;			// Indicate success.
}

////////////////////////////////////////////////////////////////////
// Open S2600.DLL and get pointers to exported DLL functions.
// Returns zero if successful, otherwise error code.
// NumMMs is the number of MMs (model 2601 modules) in your system.

GWERR S26_DLLOpen( char *workdir, int NumMMs )
{
    char dllname[256];

    if(workdir)
        sprintf(dllname, "%s\\S2600.DLL", workdir);
    else
        sprintf(dllname, "S2600.DLL");

	// Dynamically link to S2600.DLL, exit with error if link failed.
	if ( ( hlib = LoadLibrary( dllname ) ) == NULL )
		return ERR_LOAD_DLL;

	// Fill pointers to S2600.DLL functions, exit with error if attempt failed.
	if ( GetFuncPtrs() )
	{
		FreeLibrary( hlib );
		hlib = 0;
		return ERR_FUNCADDR;
	}

	// Initialize the driver.
	return S26_DriverOpen( NumMMs );
}

///////////////////////////////////////////////////////////////////
// Sever dynamic link to S2600.DLL.

void S26_DLLClose( void )
{
	// Shutdown the driver.
	S26_DriverClose();

	// Unlink from S2600.DLL.
	if ( hlib )
		FreeLibrary( hlib );
}


